import os
import re
from gensim.utils import simple_preprocess

realpath = os.path.dirname(os.path.realpath(__file__))
file_dir = realpath + '/simple_preprocess/sentences.txt'
stopwords_dir = realpath + '/utils/stopwords_id.txt'
# with open(file_dir, 'r') as reader:
#     for sentence in reader.readlines():
#         print(sentence, end='')

stopwords = list(open(stopwords_dir).read().splitlines())

def remove_stopwords(sentence):
    for w in stopwords:
        sentence = re.sub(r'\b'+w+r'\b', '', sentence)
        sentence = re.sub(r'\s+', ' ', sentence).strip()
    return sentence

sentences = list(map(remove_stopwords, open(file_dir).read().splitlines()))
corpus = list(map(simple_preprocess, sentences))
print(corpus[:2], "\nSentences: -->", len(corpus))
uniqset = set(word for l in corpus for word in l) 
print(len(uniqset), "Unique Terms")


# corpus = list(map(simple_preprocess, open(file_dir).read().splitlines()))
# print(corpus[-6:], "\nSentences: -->", len(corpus))
# uniqset = set(word for l in corpus for word in l) 
# print(len(uniqset), "Unique Terms")



import os
from gensim.models import Word2Vec
from simple_preprocess.bcapara import single_para, multi_senc_demo

SIZE = 3
WINDOW = 2
ITER = 10
WORKERS = 4


def hash(astring):
    return ord(astring[0])


# build vocabulary and train model on one paragraph
# corpus = single_para()
corpus = multi_senc_demo()
model = Word2Vec(
    corpus,
    seed=100,
    size=SIZE,
    window=WINDOW,
    min_count=2,
    workers=WORKERS,
    iter=ITER,
    hashfxn=hash,
)


# Try: kartu, rekening, maret
print(model.wv.most_similar("bca"), "\n")
# [('kredit', 0.5386360287666321),
# ('berbagai', 0.5347478985786438),
# ('sejalan', 0.502410888671875),
# ('tahapan', 0.49144789576530457),
# ('menerapkan', 0.41903647780418396),
# ('terkemuka', 0.3761982023715973),
# ('tahun', 0.3546695113182068),
# ('atm', 0.3403625190258026),
# ('nama', 0.2962668836116791)]


save_dir = os.path.dirname(os.path.realpath(__file__)) + "/model/demo.model"
print(save_dir)
# model.save(save_dir)

# model.corpus_total_words -> 139
# model.wv['bca'] # ndarray of length 10
# model.wv.vocab['atm'].count -> 5



import sys, os.path
import gensim
from gensim.models import Word2Vec

import numpy as np
import matplotlib.pyplot as plt


def plot2d(model, words=None, method="PCA", targets=[]):
    assert (
        model.vector_size >= 2
    ), "This function expects a model of size 2 (2-dimension word vectors) or higher."

    assert isinstance(targets, list), "The targets parameter expect a python list"

    if words is None:
        words = [words for words in model.wv.vocab]

    word_vec = np.array([model.wv[word] for word in words])

    if model.vector_size > 2:
        if method == "PCA":
            from sklearn.decomposition import PCA

            word_vec = PCA(2).fit_transform(word_vec)

        elif method == "TSNE":
            from sklearn.manifold import TSNE

            word_vec = TSNE(2).fit_transform(word_vec)

        else:
            raise AssertionError(
                "Model must be one of PCA or TSNE for model with greater than 2 dimensions"
            )

    with plt.style.context("seaborn-pastel"):
        plt.figure(figsize=(7, 5), dpi=180)
        plt.scatter(
            word_vec[:, 0], word_vec[:, 1], s=5, alpha=0.3, edgecolors="k", c="c"
        )

        for word, (x, y) in zip(words, word_vec):
            if word in [elem.lower() for elem in targets if targets]:
                plt.text(x - 0.02, y + 0.02, word, fontsize=5, weight="bold")
            else:
                plt.text(x - 0.02, y + 0.02, word, fontsize=5, alpha=0.5)

    plt.show()



import os
import re

realpath = os.path.dirname(os.path.realpath(__file__))

# helper function
def open_file(filename):
    filepath = realpath + "/" + filename
    wordlist = list(open(filepath).read().splitlines())
    return wordlist

def remove_words(sentence, words2remove):
    for word in words2remove:
        sentence = re.sub(r'\b' + word + r'\b', '', sentence.lower())
        sentence = re.sub(r'\s+', ' ', sentence).strip()
    return sentence

# main cleansing function
def remove_stopwords_id(sentence):
    stopwords = open_file("stopwords-id.txt")
    sentence = remove_words(sentence, stopwords)
    return sentence

def remove_region_id(sentence):
    regions = open_file("indonesian-region.txt")
    sentence = remove_words(sentence, regions)
    return sentence

def remove_vulgarity_id(sentence):
    swears = open_file("swear-words.txt")
    sentence = remove_words(sentence, swears)
    return sentence


import os
from Sastrawi.StopWordRemover.StopWordRemoverFactory import StopWordRemoverFactory

realpath = os.path.dirname(os.path.realpath(__file__))
stopwords_list_path = realpath + "/stopwords-list"
file_list = os.listdir(stopwords_list_path)

def generate_sastrawi_stopwords():
    # get Sastrawi stopwords as list
    factory = StopWordRemoverFactory()
    stopwords = factory.get_stop_words()

    # write to txt file
    with open(stopwords_list_path + '/sastrawi-stopwords.txt', 'w') as file:
        for word in stopwords:
            file.write(word + "\n")

def combine_stopwords_files(combined_filename = "stopwords-id.txt"):
    # combine all txt files
    combined_stopwords = []

    for filename in file_list:
        stopwords = open(stopwords_list_path + "/" + filename).read().splitlines()
        combined_stopwords.extend(stopwords)
        
        #print(filename, str(len(stopwords)))

    # remove duplicate and sort
    unique_stopwords = sorted(set(combined_stopwords))

    # write to new txt file
    with open(realpath + "/" + combined_filename, "w") as file:
        for word in unique_stopwords:
            file.write(word + "\n")

    #print("TOTAL", len(combined_stopwords))
    #print("UNIQUE", len(unique_stopwords))

generate_sastrawi_stopwords()
combine_stopwords_files()


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="elang",
    version="0.0.4",
    author="Samuel Chan, Tomy Tjandra",
    author_email="samuel@algorit.ma",
    description="Education toolkit for Bahasa Indonesia NLP",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/onlyphantom/elang",
    packages=setuptools.find_packages(),
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: CC0 1.0 Universal (CC0 1.0) Public Domain Dedication",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
    install_requires=["gensim", "scikit-learn", "matplotlib"],
    keywords="nlp bahasa indonesia indonesian",
)
